==> libpmemobj-cpp_1.9.orig.tar.gz: libpmemobj-cpp-1.9/tests/enumerable_thread_specific_ctor/enumerable_thread_specific_ctor.cpp <==
/*
 * Copyright 2019-2020, Intel Corporation
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 *     * Redistributions of source code must retain the above copyright
 *       notice, this list of conditions and the following disclaimer.
 *
 *     * Redistributions in binary form must reproduce the above copyright
 *       notice, this list of conditions and the following disclaimer in
 *       the documentation and/or other materials provided with the
 *       distribution.
 *
 *     * Neither the name of the copyright holder nor the names of its
 *       contributors may be used to endorse or promote products derived
 *       from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#include "unittest.hpp"

#include <libpmemobj++/detail/enumerable_thread_specific.hpp>
#include <libpmemobj++/make_persistent.hpp>

#include <set>

namespace nvobj = pmem::obj;

using test_t = size_t;
using container_type = pmem::detail::enumerable_thread_specific<test_t>;

// Adding more concurrency will increase DRD test time
const size_t concurrency = 16;

struct root {
	nvobj::persistent_ptr<container_type> pptr1;
	nvobj::persistent_ptr<container_type> pptr2;
	nvobj::persistent_ptr<container_type> pptr3;
};

int
main(int argc, char *argv[])
{
	START();

	if (argc < 2) {
		std::cerr << "usage: " << argv[0] << " file-name" << std::endl;
		return 1;
	}

	auto path = argv[1];
	auto pop = nvobj::pool<root>::create(
		path, "TLSTest: enumerable_thread_specific_ctor",
		PMEMOBJ_MIN_POOL, S_IWUSR | S_IRUSR);

	auto r = pop.root();

	try {
		nvobj::transaction::run(pop, [&] {
			r->pptr1 = nvobj::make_persistent<container_type>();
		});

		parallel_exec(concurrency, [&](size_t thread_index) {
			r->pptr1->local() = thread_index;
		});

		nvobj::transaction::run(pop, [&] {
			nvobj::delete_persistent<container_type>(r->pptr1);
			nvobj::delete_persistent<container_type>(r->pptr2);
			nvobj::delete_persistent<container_type>(r->pptr3);
		});
	} catch (std::exception &e) {
		UT_FATALexc(e);
	}

	pop.close();

	return 0;
}

==> libpmemobj-cpp_1.10.orig.tar.gz: libpmemobj-cpp-1.10/tests/enumerable_thread_specific_ctor/enumerable_thread_specific_ctor.cpp <==
// SPDX-License-Identifier: BSD-3-Clause
/* Copyright 2019-2020, Intel Corporation */

#include "unittest.hpp"

#include <libpmemobj++/detail/enumerable_thread_specific.hpp>
#include <libpmemobj++/make_persistent.hpp>

#include <set>

namespace nvobj = pmem::obj;

using test_t = size_t;
using container_type = pmem::detail::enumerable_thread_specific<test_t>;

// Adding more concurrency will increase DRD test time
const size_t concurrency = 16;

struct root {
	nvobj::persistent_ptr<container_type> pptr1;
	nvobj::persistent_ptr<container_type> pptr2;
	nvobj::persistent_ptr<container_type> pptr3;
};

static void
test(int argc, char *argv[])
{
	if (argc < 2) {
		UT_FATAL("usage: %s file-name", argv[0]);
	}

	auto path = argv[1];
	auto pop = nvobj::pool<root>::create(
		path, "TLSTest: enumerable_thread_specific_ctor",
		PMEMOBJ_MIN_POOL, S_IWUSR | S_IRUSR);

	auto r = pop.root();

	try {
		nvobj::transaction::run(pop, [&] {
			r->pptr1 = nvobj::make_persistent<container_type>();
		});

		parallel_exec(concurrency, [&](size_t thread_index) {
			r->pptr1->local() = thread_index;
			pop.persist(&r->pptr1->local(),
				    sizeof(&r->pptr1->local()));
		});

		nvobj::transaction::run(pop, [&] {
			nvobj::delete_persistent<container_type>(r->pptr1);
			nvobj::delete_persistent<container_type>(r->pptr2);
			nvobj::delete_persistent<container_type>(r->pptr3);
		});
	} catch (std::exception &e) {
		UT_FATALexc(e);
	}

	pop.close();
}

int
main(int argc, char *argv[])
{
	return run_test([&] { test(argc, argv); });
}
